<?php



/**

 * Register all actions and filters for the plugin

 *

 * @link       www.redefiningtheweb.com

 * @since      1.0.0

 *

 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor

 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/includes

 */



/**

 * Register all actions and filters for the plugin.

 *

 * Maintain a list of all hooks that are registered throughout

 * the plugin, and register them with the WordPress API. Call the

 * run function to execute the list of actions and filters.

 *

 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor

 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/includes

 * @author     RedefinignTheWeb <support@redefiningtheweb.com>

 */

class Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Loader {



	/**

	 * The array of actions registered with WordPress.

	 *

	 * @since    1.0.0

	 * @access   protected

	 * @var      array    $rtwwpge_actions    The actions registered with WordPress to fire when the plugin loads.

	 */

	protected $rtwwpge_actions;



	/**

	 * The array of filters registered with WordPress.

	 *

	 * @since    1.0.0

	 * @access   protected

	 * @var      array    $rtwwpge_filters    The filters registered with WordPress to fire when the plugin loads.

	 */

	protected $rtwwpge_filters;



	/**

	 * Initialize the collections used to maintain the actions and filters.

	 *

	 * @since    1.0.0

	 */

	public function __construct() {



		$this->rtwwpge_actions = array();

		$this->rtwwpge_filters = array();



	}



	/**

	 * Add a new action to the collection to be registered with WordPress.

	 *

	 * @since    1.0.0

	 * @param    string               $rtwwpge_hook             The name of the WordPress action that is being registered.

	 * @param    object               $rtwwpge_component        A reference to the instance of the object on which the action is defined.

	 * @param    string               $rtwwpge_callback         The name of the function definition on the $rtwwpge_component.

	 * @param    int                  $rtwwpge_priority         Optional. The priority at which the function should be fired. Default is 10.

	 * @param    int                  $rtwwpge_accepted_args    Optional. The number of arguments that should be passed to the $rtwwpge_callback. Default is 1.

	 */

	public function rtwwpge_add_action( $rtwwpge_hook, $rtwwpge_component, $rtwwpge_callback, $rtwwpge_priority = 10, $rtwwpge_accepted_args = 1 ) {

		$this->rtwwpge_actions = $this->rtwwpge_add( $this->rtwwpge_actions, $rtwwpge_hook, $rtwwpge_component, $rtwwpge_callback, $rtwwpge_priority, $rtwwpge_accepted_args );

	}



	/**

	 * Add a new filter to the collection to be registered with WordPress.

	 *

	 * @since    1.0.0

	 * @param    string               $rtwwpge_hook             The name of the WordPress filter that is being registered.

	 * @param    object               $rtwwpge_component        A reference to the instance of the object on which the filter is defined.

	 * @param    string               $rtwwpge_callback         The name of the function definition on the $rtwwpge_component.

	 * @param    int                  $rtwwpge_priority         Optional. The priority at which the function should be fired. Default is 10.

	 * @param    int                  $rtwwpge_accepted_args    Optional. The number of arguments that should be passed to the $rtwwpge_callback. Default is 1

	 */

	public function rtwwpge_add_filter( $rtwwpge_hook, $rtwwpge_component, $rtwwpge_callback, $rtwwpge_priority = 10, $rtwwpge_accepted_args = 1 ) {

		$this->rtwwpge_filters = $this->rtwwpge_add( $this->rtwwpge_filters, $rtwwpge_hook, $rtwwpge_component, $rtwwpge_callback, $rtwwpge_priority, $rtwwpge_accepted_args );

	}



	/**

	 * A utility function that is used to register the actions and hooks into a single

	 * collection.

	 *

	 * @since    1.0.0

	 * @access   private

	 * @param    array                $rtwwpge_hooks            The collection of hooks that is being registered (that is, actions or filters).

	 * @param    string               $rtwwpge_hook             The name of the WordPress filter that is being registered.

	 * @param    object               $rtwwpge_component        A reference to the instance of the object on which the filter is defined.

	 * @param    string               $rtwwpge_callback         The name of the function definition on the $component.

	 * @param    int                  $rtwwpge_priority         The priority at which the function should be fired.

	 * @param    int                  $rtwwpge_accepted_args    The number of arguments that should be passed to the $rtwwpge_callback.

	 * @return   array                                  The collection of actions and filters registered with WordPress.

	 */

	private function rtwwpge_add( $rtwwpge_hooks, $rtwwpge_hook, $rtwwpge_component, $rtwwpge_callback, $rtwwpge_priority, $rtwwpge_accepted_args ) {



		$rtwwpge_hooks[] = array(

			'hook'          => $rtwwpge_hook,

			'component'     => $rtwwpge_component,

			'callback'      => $rtwwpge_callback,

			'priority'      => $rtwwpge_priority,

			'accepted_args' => $rtwwpge_accepted_args

		);



		return $rtwwpge_hooks;



	}



	/**

	 * Register the filters and actions with WordPress.

	 *

	 * @since    1.0.0

	 */

	public function rtwwpge_run() {



		foreach ( $this->rtwwpge_filters as $rtwwpge_hook ) {

			add_filter( $rtwwpge_hook['hook'], array( $rtwwpge_hook['component'], $rtwwpge_hook['callback'] ), $rtwwpge_hook['priority'], $rtwwpge_hook['accepted_args'] );

		}



		foreach ( $this->rtwwpge_actions as $rtwwpge_hook ) {

			add_action( $rtwwpge_hook['hook'], array( $rtwwpge_hook['component'], $rtwwpge_hook['callback'] ), $rtwwpge_hook['priority'], $rtwwpge_hook['accepted_args'] );

		}



	}



}

